local _G = _G
local AceConfig = LibStub("AceConfig-3.0")
local AceConfigDialog = LibStub("AceConfigDialog-3.0")
local AceDBOptions = LibStub("AceDBOptions-3.0")
local L = PetSelector.L

--First visible frame
local function createMainPanel()

	local frame = CreateFrame("Frame", "PetSelectorOptionsMain")
	local title = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	local version = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	local author = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")

	title:SetFormattedText("|T%s:%d|t %s", "Interface\\ICONS\\Ability_Hunter_BestialDiscipline", 32, "Pet Selector")
	title:SetPoint("CENTER", frame, "CENTER", 0, 170)

	version:SetText(_G.GAME_VERSION_LABEL .. " " .. GetAddOnMetadata("PetSelector", "Version"))
	version:SetPoint("CENTER", frame, "CENTER", 0, 130)

	author:SetText(L["Author"] .. ": Deepac")
	author:SetPoint("CENTER", frame, "CENTER", 0, 100)

	return frame

end

--options frame
local checkPanel = {
	order = 1,
	type = "group",
	name = _G.MAIN_MENU,
	args = {
		hidecheck = {
			order = 1,
			type = "toggle",
			name = L["Only show when in a party"],
			width = "full",
			get = function() return PetSelector.db.profile.showinparty end,
			set = function(info, value) 
					PetSelector.db.profile.showinparty = not PetSelector.db.profile.showinparty 
					PetSelector:DisplayFrames()
				end,
		},
		stabled = {
			order = 2,
			type = "toggle",
			name = L["Include stabled pets"],
			width = "full",
			get = function() return PetSelector.db.profile.stabled end,
			set = function(info, value)
					PetSelector.db.profile.stabled = not PetSelector.db.profile.stabled
					PetSelector:SetPet()
				end,
		},
		buffsframe = {
			order = 3,
			type = "toggle",
			name = L["Show buffs frame"],
			width = "full",
			get = function() return PetSelector.db.profile.showbuffs end,
			set = function(info, value)
					PetSelector.db.profile.showbuffs = not PetSelector.db.profile.showbuffs
					PetSelector:DisplayFrames()
				end,
		},
		lockcheck = {
			order = 4,
			type = "toggle",
			name = L["Lock position"],
			width = "full",
			get = function() return PetSelector.db.profile.locked end,
			set = function(info, value) PetSelector.db.profile.locked = not PetSelector.db.profile.locked end,
		},
		spacer1 = {
			order = 5,
			type = "description",
			name = "\n",
		},
		scale = {
			order = 6,
			type = 'range',
			name = _G.UI_SCALE,
			min = 0.25,
			max = 2.0,
			isPercent = true,
			step = 0.01,
			width = 'full',
			get = function() return PetSelector.db.profile.scale end,
			set = 
				function(info, value)
					PetSelector.db.profile.scale = value
					PetSelectorMainFrame:SetScale(value)
				end,
		},
	},
}

--respond to Default button/Profile reset
function PetSelector:profileReset()

	local f = PetSelectorMainFrame
	local b = PetSelectorBuffFrame
	
	f:SetScale(self.db.profile.scale)
	f:ClearAllPoints()
	f:SetPoint("BOTTOMLEFT", UIParent, "BOTTOMLEFT", self.db.profile.x, self.db.profile.y)
	
	b:SetScale(self.db.profile.scale)
	b:ClearAllPoints()
	b:SetPoint("BOTTOMLEFT", UIParent, "BOTTOMLEFT", self.db.profile.bx, self.db.profile.by)
	
	PetSelector:DisplayFrames()
	
end

--Setup options
function PetSelector:createPetSelectorOptions()

	local mainPanel = createMainPanel()
	
	mainPanel.name = "Pet Selector"
	InterfaceOptions_AddCategory(mainPanel)
	--make sure Pet Selector's reset sub is called in response to a profile reset
	self.db.RegisterCallback(self, "OnProfileReset", "profileReset")
	AceConfig:RegisterOptionsTable("PetSelectorCheck", checkPanel)
	AceConfig:RegisterOptionsTable("PetSelectorProfiles", AceDBOptions:GetOptionsTable(self.db))
	self.optionschecks = AceConfigDialog:AddToBlizOptions("PetSelectorCheck", _G.MAIN_MENU, "Pet Selector")
	--make sure Pet Selector's reset function is call in response to the user clicking the Default button
	self.optionschecks.default = function() self.db:ResetProfile() end
	AceConfigDialog:AddToBlizOptions("PetSelectorProfiles", L["Profiles"], "Pet Selector")
	
end